==> neo4j-kernel-2.3.6-sources.jar: org/neo4j/unsafe/impl/batchimport/cache/idmapping/string/TrackerFactories.java <==
/*
 * Copyright (c) 2002-2016 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.unsafe.impl.batchimport.cache.idmapping.string;

import org.neo4j.unsafe.impl.batchimport.cache.NumberArrayFactory;

import static org.neo4j.unsafe.impl.batchimport.cache.idmapping.string.AbstractTracker.DEFAULT_VALUE;

/**
 * Common {@link TrackerFactory} implementations.
 */
public class TrackerFactories
{
    /**
     * @return {@link TrackerFactory} creating different {@link Tracker} instances depending on size.
     */
    public static TrackerFactory dynamic()
    {
        return new TrackerFactory()
        {
            @Override
            public Tracker create( NumberArrayFactory arrayFactory, long size )
            {
                return size > Integer.MAX_VALUE
                        ? new LongTracker( arrayFactory.newLongArray( size, DEFAULT_VALUE ) )
                        : new IntTracker( arrayFactory.newIntArray( size, DEFAULT_VALUE ) );
            }
        };
    }
}

==> neo4j-kernel-3.1.6-sources.jar: org/neo4j/unsafe/impl/batchimport/cache/idmapping/string/TrackerFactories.java <==
/*
 * Copyright (c) 2002-2017 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.unsafe.impl.batchimport.cache.idmapping.string;

import org.neo4j.unsafe.impl.batchimport.cache.NumberArrayFactory;


/**
 * Common {@link TrackerFactory} implementations.
 */
public class TrackerFactories
{
    /**
     * @return {@link TrackerFactory} creating different {@link Tracker} instances depending on size.
     */
    public static TrackerFactory dynamic()
    {
        return new TrackerFactory()
        {
            @Override
            public Tracker create( NumberArrayFactory arrayFactory, long size )
            {
                return size > Integer.MAX_VALUE
                        ? new BigIdTracker( arrayFactory.newByteArray( size, BigIdTracker.DEFAULT_VALUE ) )
                        : new IntTracker( arrayFactory.newIntArray( size, IntTracker.DEFAULT_VALUE ) );
            }
        };
    }
}
